summaryrefslogtreecommitdiffstats
path: root/scripts/automation/trex_control_plane/client_utils/trex_yaml_gen.py
diff options
context:
space:
mode:
authorDan Klein <danklein10@gmail.com>2015-10-01 09:15:22 +0300
committerDan Klein <danklein10@gmail.com>2015-10-01 09:15:22 +0300
commitca479ac9bb1e4d1a5953e9d121ab39a29f7b8b8e (patch)
treedb804072dcd60f312e0108895692ac829f940426 /scripts/automation/trex_control_plane/client_utils/trex_yaml_gen.py
parent6f12f984a9ef37997a9dd614e2d7436ee1f9875a (diff)
Updated control plain documentation with typos and T-Rex changed to TRex.
Diffstat (limited to 'scripts/automation/trex_control_plane/client_utils/trex_yaml_gen.py')
-rwxr-xr-xscripts/automation/trex_control_plane/client_utils/trex_yaml_gen.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/scripts/automation/trex_control_plane/client_utils/trex_yaml_gen.py b/scripts/automation/trex_control_plane/client_utils/trex_yaml_gen.py
index 755674ea..351b7b9c 100755
--- a/scripts/automation/trex_control_plane/client_utils/trex_yaml_gen.py
+++ b/scripts/automation/trex_control_plane/client_utils/trex_yaml_gen.py
@@ -7,7 +7,7 @@ import os
class CTRexYaml(object):
"""
This class functions as a YAML generator according to T-Rex YAML format.
CTRexYaml is compatible with both Python 2 and Python 3.
"""
@@ -38,7 +38,7 @@ class CTRexYaml(object):
:parameters:
trex_files_path : str
a path (on T-Rex server side) for the pcap files using which T-Rex can access it.
"""
self.yaml_obj = list(CTRexYaml.YAML_TEMPLATE)
@@ -193,7 +193,7 @@ class CTRexYaml(object):
"""
Returns a list of all files related to the YAML object, including the YAML filename itself.
- .. tip:: This method is especially useful for listing all the files that should be pushed to T-Rex server as part of the same yaml selection.
+ .. tip:: This method is especially useful for listing all the files that should be pushed to TRex server as part of the same yaml selection.
:parameters:
None
@@ -7,7 +7,7 @@ import os
class CTRexYaml(object):
"""
- This class functions as a YAML generator according to T-Rex YAML format.
+ This class functions as a YAML generator according to TRex YAML format.
CTRexYaml is compatible with both Python 2 and Python 3.
"""
@@ -38,7 +38,7 @@ class CTRexYaml(object):
:parameters:
trex_files_path : str
- a path (on T-Rex server side) for the pcap files using which T-Rex can access it.
+ a path (on TRex server side) for the pcap files using which TRex can access it.
"""
self.yaml_obj = list(CTRexYaml.YAML_TEMPLATE)